package com.training.controller;

import java.util.ArrayList;
import java.util.List;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import com.training.model.User;


@Controller
public class UserController {
	
	/**
	 * 增加用户 REST
	 * @param user
	 * @return
	 */
	@RequestMapping(value="/user", method = RequestMethod.POST)
	public ModelAndView create(User user) {
		System.out.println("=== begin to get user information ===");
		System.out.println("=== user name: " + user.getName() + "===");
		System.out.println("=== user address: " + user.getAddress() + "===");
		ModelAndView mv = new ModelAndView("user/success");
		mv.addObject("user", user);
		return mv;
	}
	
	/**
	 * 删除用户REST
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/user/{id}", method = RequestMethod.DELETE)
	public ModelAndView delete(@PathVariable int id) {
		System.out.println("删除ID为: " + id);
		//======从数据库中删除,省略========================
		ModelAndView mv = new ModelAndView("user/message");
		mv.addObject("message", "删除信息成功");
		return mv;
	}	

	/**
	 * 更新User
	 * @param user
	 * @return
	 */
	@RequestMapping(value="/user", method = RequestMethod.PUT)
	public ModelAndView update(User user) {
		System.out.println("更改User Id: " + user.getId());
		//======更新数据,省略========================
		ModelAndView mv = new ModelAndView("user/message");
		mv.addObject("message", "更新信息成功");
		return mv;
	}
	
	/**
	 * 删除用户REST
	 * @param id
	 * @return
	 */
	@RequestMapping(value="/user/{id}", method = RequestMethod.GET)
	public ModelAndView get(@PathVariable int id) {
		System.out.println("得到ID为: " + id);
		//======从数据库中获取用户信息,省略========================
		ModelAndView mv = new ModelAndView("user/message");
		mv.addObject("message", "得到信息成功");
		return mv;
	}	
	
	/**
	 * 进入测试首页
	 * @return
	 */
	@RequestMapping(value="/index", method = RequestMethod.GET)
	public String index() {		
		return "user/index";
	}
	
	
	/**
	 * 进入新增页面
	 * @param user
	 * @return
	 */
	@RequestMapping(value="/add", method = RequestMethod.GET)
	public String addPage() {		
		return "user/add";
	}
	
	/**
	 * 进入编辑页面
	 * @param user
	 * @return
	 */
	@RequestMapping(value="/edit", method = RequestMethod.GET)
	public String editPage() {		
		return "user/edit";
	}
	
	/**
	 * 进入得到用户界面
	 * @return
	 */
	@RequestMapping(value="/get", method = RequestMethod.GET)
	public String getPage() {		
		return "user/get";
	}
	
	/**
	 * 进入删除页面
	 * @return
	 */
	@RequestMapping(value="/delete", method = RequestMethod.GET)
	public String deletePage() {		
		return "user/delete";
	}
	
	@ResponseBody
	@RequestMapping(value="/users", method = RequestMethod.GET)
	public List<User> getUsers() {	
		//模拟从数据库中获得数据....
		List<User> users = new ArrayList<User>();
		for(int i = 0; i< 20; i++){
			User user = new User();
			user.setId(i);
			user.setName("Name: " + i);
			user.setAddress("Address: " + i);
			users.add(user);
		}
		return users;
 	}
	

}
